@@ -47,6 +47,12 @@ func NewSortedFilesFromPaths(paths []string, opts SymlinkAllowOpts) ([]*File, er
 
 		relativePath := ""
 		pathPieces := strings.Split(path, "=")
+		if strings.HasPrefix(pathPieces[0], "http://") || strings.HasPrefix(pathPieces[0], "https://") {
+			pathPieces = []string{path}
+		} else if len(pathPieces) > 1 && (strings.HasPrefix(pathPieces[1], "http://") || strings.HasPrefix(pathPieces[1], "https://")) {
+			pathPieces[1] = strings.Join(pathPieces[1:], "=")
+			pathPieces = pathPieces[0:2]
+		}
 
 		switch len(pathPieces) {
 		case 1:
